HaltReason

Enum HaltReason 

pub enum HaltReason {
Show 35 variants OutOfGas(OutOfGasError), OpcodeNotFound, InvalidFEOpcode, InvalidJump, NotActivated, StackUnderflow, StackOverflow, OutOfOffset, CreateCollision, PrecompileError, NonceOverflow, CreateContractSizeLimit, CreateContractStartingWithEF, CreateInitCodeSizeLimit, OverflowPayment, StateChangeDuringStaticCall, CallNotAllowedInsideStatic, OutOfFunds, CallTooDeep, RootCallOnly, MalformedBuiltinParams, CallDepthOverflow, NonNegativeExitCode, UnknownError, InputOutputOutOfBounds, UnreachableCodeReached, MemoryOutOfBounds, TableOutOfBounds, IndirectCallToNull, IntegerDivisionByZero, IntegerOverflow, BadConversionToInteger, BadSignature, OutOfFuel, UnknownExternalFunction,
}
Indicates that the EVM has experienced an exceptional halt.

This causes execution to immediately end with all gas being consumed.

Variants



OutOfGas(OutOfGasError)

Out of gas error.



OpcodeNotFound

Opcode not found error.



InvalidFEOpcode

Invalid FE opcode error.



InvalidJump

Invalid jump destination.



NotActivated

The feature or opcode is not activated in hardfork.



StackUnderflow

Attempting to pop a value from an empty stack.



StackOverflow

Attempting to push a value onto a full stack.



OutOfOffset

Invalid memory or storage offset for state::bytecode::opcode::RETURNDATACOPY.



CreateCollision

Address collision during contract creation.



PrecompileError

Precompile error.



NonceOverflow

Nonce overflow.



CreateContractSizeLimit

Create init code size exceeds limit (runtime).



CreateContractStartingWithEF

Error on created contract that begins with EF



CreateInitCodeSizeLimit

EIP-3860: Limit and meter initcode. Initcode size limit exceeded.



OverflowPayment

Overflow payment. Not possible to happen on mainnet.



StateChangeDuringStaticCall

State change during static call.



CallNotAllowedInsideStatic

Call not allowed inside static call.



OutOfFunds

Out of funds to pay for the call.



CallTooDeep

Call is too deep.



RootCallOnly

Function can only be invoked as the root entry call



MalformedBuiltinParams

Builtin function received malformed or invalid parameters



CallDepthOverflow

Exceeded maximum allowed call stack depth



NonNegativeExitCode

Exit code must be non-negative, but a negative value was used



UnknownError

Generic catch-all error for unknown failures



InputOutputOutOfBounds

I/O operation tried to read/write outside allowed buffer bounds



UnreachableCodeReached

Execution reached a code path marked as unreachable



MemoryOutOfBounds

Memory access outside the allocated memory range



TableOutOfBounds

Table index access outside the allocated table range



IndirectCallToNull

Indirect function call attempted with a null function reference



IntegerDivisionByZero

Division or remainder by zero occurred



IntegerOverflow

Integer arithmetic operation overflowed the allowed range



BadConversionToInteger

Invalid conversion to integer (e.g., from NaN or out-of-range value)



BadSignature

Function signature mismatch in a call



OutOfFuel

Execution ran out of allocated fuel/gas



UnknownExternalFunction

Call an undefined or unregistered external function